@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright 2003-2018 The Music Player Daemon Project
+ * Copyright 2003-2021 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,26 +34,28 @@
 int
 stdinToArgArray(char ***array)
 {
-	List *list = makeList();
+	struct List list;
+	makeList(&list);
+
 	char buffer[4096];
 
 	while (fgets(buffer, sizeof(buffer), stdin)) {
 		char *sp;
 		if((sp = strchr(buffer,'\n'))) *sp = '\0';
-		insertInListWithoutKey(list,strdup(buffer));
+		insertInListWithoutKey(&list, strdup(buffer));
 	}
 
-	const unsigned size = list->numberOfNodes;
+	const unsigned size = list.numberOfNodes;
 	*array = malloc((sizeof(char *))*size);
 	unsigned i = 0;
-	ListNode * node = list->firstNode;
+	struct ListNode *node = list.firstNode;
 	while(node) {
 		(*array)[i++] = (char *)node->data;
 		node = node->nextNode;
 	}
 	assert(i==size);
 
-	freeList(list);
+	freeList(&list);
 
 	return size;
 }
