@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright 2003-2018 The Music Player Daemon Project
+ * Copyright 2003-2021 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,58 +23,48 @@
 #include <stdlib.h>
 #include <assert.h>
 
-List *makeList(void) {
-	List * list = malloc(sizeof(List));
-
+void
+makeList(struct List *list)
+{
 	assert(list!=NULL);
 
 	list->firstNode = NULL;
-	list->lastNode = NULL;
+	list->tail = &list->firstNode;
 	list->numberOfNodes = 0;
-
-	return list;
 }
 
-void insertInListWithoutKey(List * list, void * data) {
-	ListNode * node;
+void
+insertInListWithoutKey(struct List *list, void * data) {
+	struct ListNode *node;
 
 	assert(list!=NULL);
 	assert(data!=NULL);
 
-	node = malloc(sizeof(ListNode));
+	node = malloc(sizeof(*node));
 	assert(node!=NULL);
 
-	if(list->firstNode==NULL) {
-		assert(list->lastNode==NULL);
-		list->firstNode = node;
-	}
-	else {
-		assert(list->lastNode!=NULL);
-		assert(list->lastNode->nextNode==NULL);
-		list->lastNode->nextNode = node;
-	}
-
 	node->data = data;
 	node->nextNode = NULL;
 
-	list->lastNode = node;
+	*list->tail = node;
+	list->tail = &node->nextNode;
 
 	list->numberOfNodes++;
 }
 
-void freeList(void * list) {
-	ListNode * tmpNode;
-	ListNode * tmpNode2;
+void
+freeList(struct List *list)
+{
+	struct ListNode * tmpNode;
+	struct ListNode * tmpNode2;
 
 	assert(list!=NULL);
 
-	tmpNode = ((List *)list)->firstNode;
+	tmpNode = list->firstNode;
 
 	while(tmpNode!=NULL) {
 		tmpNode2 = tmpNode->nextNode;
 		free(tmpNode);
 		tmpNode = tmpNode2;
 	}
-
-	free(list);
 }
