@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright 2003-2018 The Music Player Daemon Project
+ * Copyright 2003-2021 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,34 +21,34 @@
 #ifndef LIST_H
 #define LIST_H
 
-typedef struct _ListNode {
+struct ListNode {
 	/* data store in node */
 	void * data;
 	/* next node in list */
-	struct _ListNode * nextNode;
-} ListNode;
+	struct ListNode *nextNode;
+};
 
-typedef struct _List {
+struct List {
 	/* first node in list */
-	ListNode * firstNode;
+	struct ListNode *firstNode;
 	/* last node in list */
-	ListNode * lastNode;
+	struct ListNode **tail;
 	/* number of nodes */
 	long numberOfNodes;
-} List;
+};
 
-/* allocates memory for a new list and initializes it
- *  _freeDataFunc_ -> pointer to function used to free data, use 
- *                    DEFAULT_FREE_DATAFUNC to use free()
- * returns pointer to new list if successful, NULL otherwise
+/* initializes the list
  */
-List *makeList(void);
+void
+makeList(struct List *list);
 
-void insertInListWithoutKey(List * list,void * data);
+void
+insertInListWithoutKey(struct List *list, void *data);
 
 /* frees memory malloc'd for list and its nodes
  *  _list_ -> List to be free'd
  */
-void freeList(void * list);
+void
+freeList(struct List *list);
 
 #endif
